version 14
cap log close
clear *
set more off

log using allgamesindividuals.log, replace

use "dataset players.dta"

*****************************************************VARIABLE GENERATION**************************************************

*generate the team values for Transfermarkt 
bysort matchteam_id: egen tot=total(value)
bysort matchteam_id: egen avvalue=mean(value)
bysort matchteam_id: egen sd=sd(value)
bysort matchteam_id: egen max=max(value)
bysort matchteam_id: egen min=min(value)
bysort matchteam_id: egen med=median(value)
bysort matchteam_id: egen number=count(value)

*generate values for well supported teams in the crowd
gen playteamsupported=1 		if playteamrelfans>0.01 
replace playteamsupported=0		if playteamsupported==.

bysort matchteam_id: egen numbersupported=total(playteamsupported)

gen indsupportvalue=playteamrelfans*value
bysort matchteam_id: egen support=mean(playteamfans+1)
bysort matchteam_id: egen supportvalue=mean(indsupportvalue)

*************************************************************rematch at the game level****************************************

collapse day month year home homereal uefa conmebol fifapoints fifarank wcqual10 wcqual14 euro12qual euro12 europo copam wc10 match_id team_id  ///
res go margin tot* av* sd max min med number* support supportvalue playteamrel* winodds drawodds ///
lossodds odd*, by(matchteam_id team group)

sort match_id home 

tempfile playerlevel

save `playerlevel'

for var home homereal team_id uefa conmebol fifapoints fifarank go res margin matchteam_id team tot av* sd max min med number ///
support supportvalue playteamrel* numbersupported winodds: rename X op_X
rename lossodds		winodds
rename op_winodds	lossodds

gen home=abs(op_home-1)

sort match_id home

merge 1:1 match_id home using `playerlevel', update replace

drop _merge
drop if avvalue==.
drop if op_avvalue==.
gen date=mdy(month,day,year)

tab uefa conmebol
drop if conmebol==uefa
drop if op_conmebol==op_uefa

************************Make variables to merge the ELO dataset****************
sort date
gen seqnum=_n
bysort team_id op_team_id year month: egen lastmonthgame=max(seqnum)
bysort team_id op_team_id year month: egen firstmonthgame=min(seqnum)

gen monthgamenumber=2 if lastmonthgame==seqnum
replace monthgamenumber=1 if firstmonthgame==seqnum

sum month*

save allgamesplayers.dta, replace

*******************************************ADD THE ELO DATA***************************************

use elofile.dta, replace

************************Make variables to merge****************

gen date=mdy(month,day,year)
sort date
gen seqnum=_n
bysort team_id op_team_id year month: egen lastmonthgame=max(seqnum)
bysort team_id op_team_id year month: egen firstmonthgame=min(seqnum)

gen monthgamenumber=2 if lastmonthgame==seqnum
replace monthgamenumber=1 if firstmonthgame==seqnum

sum month*

tempfile elofile2

save `elofile2'

use allgamesplayers.dta, replace

merge 1:1 team_id op_team_id year month monthgamenumber using `elofile2'

***Check the correpondance

drop if matchteam_id==.
drop check 

sort match_id
gen check=1 if elostart[_n]==op_elostart[_n-1] & match_id[_n]==match_id[_n-1]
replace check=1 if elostart[_n]==op_elostart[_n+1] & match_id[_n]==match_id[_n+1]
sum elostart op_elostart date check

*****************************SET UP VARIABLE FOR RANDOM SELECTION OF 1 OBS PER GAME ***********************
*each 1st game home, second away
sort match_id home
gen selectorsetup=_n-int(_n/4)*4
tab selectorsetup

gen selector=1			if selectorsetup==0 
replace selector=1		if selectorsetup==1 
replace selector=0 		if selector==.

bysort match_id: egen meanselector=mean(selector)
sum meanselector

tab homereal selector

*set constraint for oprobit
constraint def 1 [cut1]_cons = -[cut2]_cons

***************************************RESCALING AND EXTRA GENERATION*********************************
*generate the wins-points
gen win=1 		if res==2
replace win=0	if win==.
gen draw=1		if res==1
replace draw=0	if draw==.
gen loss=1 	if res==0
replace loss=0 if loss==.

**For estimation on the difference
gen difhomereal=homereal-op_homereal
gen ldifavvalue=log(avvalue/op_avvalue)
gen ldifsq=log(avvalue/op_avvalue)^2
gen ldifsd=log(sd/avvalue*op_avvalue/op_sd)
gen ldifmax=log(max/avvalue*op_avvalue/op_max)
gen ldifmin=log(min/avvalue*op_avvalue/op_min)
gen ldifmed=log(med/avvalue*op_avvalue/op_med)

**Alternative forecasters
gen ldifnumber=log(number/op_number)
gen ldiffifapoints=log((fifapoints+1)/(op_fifapoints+1))
gen ldifelopoints=log(elostart/op_elostart)

*bias in supported teams?
gen ldifnumbersupported=log((numbersupported+1)/(op_numbersupported+1))
gen ldifsupport=log(support/op_support)
gen ldifsupportvalue=log((supportvalue+1)/(op_supportvalue+1))
gen difplayteamrelfans=playteamrelfans-op_playteamrelfans

egen country_id=group(team_id)
sum country_id team_id uefa conmebol op_uefa op_conmebol

save allgamesplayers.dta, replace


*************************************************************ESTIMATION MATCH OUTCOME PART**********************************************************************
local games=r(N)/2

**summary stats of estimation sample => Table 1 and 2 in paper
sum loss draw win margin lossodds drawodds winodds odd_win odd_draw odd_loss avvalue op_avvalue fifapoints op_fifapoints elostart op_elostart ///
homereal op_homereal number* op_number* support* op_support* playteamrelfans op_playteamrelfans wcqual10 wcqual14 euro12 euro12qual copa* europo wc10 if selector==1

************************************BASE MODEL*******************************************

*Baseline regression
oprobit res difhomereal ldifavvalue ldifnumber if selector==1, constraint(1)
estat ic, n(`games')
predict losshat drawhat winhat
outreg2 using Table3a.xls, replace keep(difhomereal ldifavvalue ldifnumber) addstat(Log Likelihood, e(ll)) slow(750) dec(3) ctitle(Crowd)		 
outreg2 using Table8.xls, replace keep(difhomereal ldifavvalue ldifnumber) addstat(Log Likelihood, e(ll)) slow(750) dec(3) ctitle(Game result) 	
outreg2 using Tableapp.xls, replace keep(difhomereal ldifavvalue ldifnumber) addstat(Log Likelihood, e(ll)) slow(750) dec(3) ctitle(base) 			
outreg2 using Table3b.xls, replace keep(difhomereal ldifavvalue ldifnumber) addstat(Log Likelihood, e(ll)) slow(750) dec(3) ctitle(oprobit) 		

*other tries with distributional measures of TM values:
oprobit res difhomereal ldifavvalue ldifnumber ldifsd if selector==1, constraint(1) 
estat ic, n(`games')
outreg2 using Tableapp.xls, append keep(difhomereal ldifavvalue ldifnumber ldifsd)  addstat(Log Likelihood, e(ll)) slow(750) dec(3) ctitle(sd) 

oprobit res difhomereal ldifavvalue ldifnumber ldifmax if selector==1, constraint(1) 
estat ic, n(`games')
outreg2 using Tableapp.xls, append keep(difhomereal ldifavvalue ldifnumber ldifmax)  addstat(Log Likelihood, e(ll)) slow(750) dec(3) ctitle(max) 

oprobit res difhomereal ldifavvalue ldifnumber ldifmin if selector==1, constraint(1) 
estat ic, n(`games')
outreg2 using Tableapp.xls, append keep(difhomereal ldifavvalue ldifnumber ldifmin)  addstat(Log Likelihood, e(ll)) slow(750) dec(3) ctitle(min) 

oprobit res difhomereal ldifavvalue ldifnumber ldifmed if selector==1, constraint(1) 
estat ic, n(`games')
outreg2 using Tableapp.xls, append keep(difhomereal ldifavvalue ldifnumber ldifmed)  addstat(Log Likelihood, e(ll)) slow(750) dec(3) ctitle(median) 

oprobit res difhomereal ldifavvalue ldifnumber ldifsq if selector==1, constraint(1) 
estat ic, n(`games')
outreg2 using Tableapp.xls, append keep(difhomereal ldifavvalue ldifnumber ldifsq)  addstat(Log Likelihood, e(ll)) slow(750) dec(3) ctitle(median) 

oprobit res difhomereal ldifavvalue ldifnumber ldifsd ldifmax ldifmin ldifmed if selector==1, constraint(1) 
estat ic, n(`games')
outreg2 using Tableapp.xls, append keep(difhomereal ldifavvalue ldifnumber ldifsd ldifmax ldifmin ldifmed) addstat(Log Likelihood, e(ll)) slow(750) dec(3) ctitle(all) 

*tries with other estimation methods:
ologit res difhomereal ldifavvalue ldifnumber if selector==1, constraint(1)
estat ic, n(`games')
predict losslogit drawlogit winlogit
outreg2 using Table3b.xls, append keep(difhomereal ldifavvalue ldifnumber) addstat(Log Likelihood, e(ll)) slow(750) dec(3) ctitle(ologit) 

mlogit res difhomereal ldifavvalue ldifnumber if selector==1, constraint(1)
estat ic, n(`games')
predict lossmlogit drawmlogit winmlogit
outreg2 using Table3b.xls, append keep(difhomereal ldifavvalue ldifnumber) addstat(Log Likelihood, e(ll)) slow(750) dec(3) ctitle(mlogit) 

********************************************ALTERNATIVE PREDICTORS**************************************
*Odds no estimation needed
*FIFA
oprobit res difhomereal ldiffifapoints ldifnumber if selector==1, constraint(1) 
estat ic, n(`games')
predict lossfifa drawfifa winfifa
outreg2 using Table3a.xls, append keep(difhomereal ldiffifapoints ldifnumber) addstat(Log Likelihood, e(ll)) slow(750) dec(3) ctitle(FIFA) 

oprobit res difhomereal ldiffifapoints if selector==1, constraint(1) 
estat ic, n(`games')
outreg2 using Table3a.xls, append keep(difhomereal ldiffifapoints) addstat(Log Likelihood, e(ll)) slow(750) dec(3) ctitle(FIFA) 

*ELO points
oprobit res difhomereal ldifelopoints ldifnumber if selector==1, constraint(1) 
estat ic, n(`games')
predict losselo drawelo winelo
outreg2 using Table3a.xls, append keep(difhomereal ldifelopoints ldifnumber) addstat(Log Likelihood, e(ll)) slow(750) dec(3) ctitle(ELO) 

oprobit res difhomereal ldifelopoints if selector==1, constraint(1) 
estat ic, n(`games')
outreg2 using Table3a.xls, append keep(difhomereal ldifelopoints) addstat(Log Likelihood, e(ll)) slow(750) dec(3) ctitle(ELO) 

***************************************GOAL MARGIN MODEL*************************************
*baseline
reg margin difhomereal ldifavvalue ldifnumber if selector==1
estat ic, n(`games')
outreg2 using Table3a.xls, append slow(750) dec(3) ctitle(Crowd) 

reg margin difhomereal ldiffifapoints ldifnumber if selector==1
estat ic, n(`games')
outreg2 using Table3a.xls, append  slow(750) dec(3) ctitle(FIFA)

reg margin difhomereal ldiffifapoints if selector==1
estat ic, n(`games')
outreg2 using Table3a.xls, append  slow(750) dec(3) ctitle(FIFA)

reg margin difhomereal ldifelopoints ldifnumber if selector==1
estat ic, n(`games')
outreg2 using Table3a.xls, append slow(750) dec(3) ctitle(ELO)

reg margin difhomereal ldifelopoints if selector==1
estat ic, n(`games')
outreg2 using Table3a.xls, append slow(750) dec(3) ctitle(ELO)

*******************************************BIASES BY NUMBER OF FANS?**************************************
*look at correlation of bias measures
correl ldifavvalue ldifnumber ldifsupport playteamrelfans ldifnumbersupported ldifsupportvalue

*game outcome model
oprobit res difhomereal ldifavvalue ldifnumber ldifsupport if selector==1, constraint(1) 
estat ic, n(`games') 
outreg2 using Table8.xls, append keep(difhomereal ldifavvalue ldifnumber ldifsupport) addstat(Log Likelihood, e(ll)) slow(750) dec(3) ctitle(game result)

oprobit res difhomereal ldifavvalue ldifnumber difplayteamrelfans if selector==1, constraint(1) 
estat ic, n(`games') 
outreg2 using Table8.xls, append keep(difhomereal ldifavvalue ldifnumber difplayteamrelfans) addstat(Log Likelihood, e(ll)) slow(750) dec(3) ctitle(game result)

oprobit res difhomereal ldifavvalue ldifnumber ldifnumbersupported if selector==1, constraint(1) 
estat ic, n(`games') 
outreg2 using Table8.xls, append keep(difhomereal ldifavvalue ldifnumber ldifnumbersupported) addstat(Log Likelihood, e(ll)) slow(750) dec(3) ctitle(game result)
predict losssup	drawsup winsup

oprobit res difhomereal ldifavvalue ldifnumber ldifsupportvalue if selector==1, constraint(1) 
estat ic, n(`games') 
outreg2 using Table8.xls, append keep(difhomereal ldifavvalue ldifnumber ldifsupportvalue) addstat(Log Likelihood, e(ll)) slow(750) dec(3) ctitle(game result)

***Goal margin model
reg margin difhomereal ldifavvalue ldifnumber if selector==1
estat ic, n(`games')
outreg2 using Table8.xls, append keep(difhomereal ldifavvalue ldifnumber) slow(750) dec(3) ctitle(goal margin)  

reg margin difhomereal ldifavvalue ldifnumber ldifsupport if selector==1 
estat ic, n(`games') 
outreg2 using Table8.xls, append keep(difhomereal ldifavvalue ldifnumber ldifsupport) slow(750) dec(3) ctitle(goal margin) 

reg margin difhomereal ldifavvalue ldifnumber difplayteamrelfans if selector==1 
estat ic, n(`games') 
outreg2 using Table8.xls, append keep(difhomereal ldifavvalue ldifnumber difplayteamrelfans) slow(750) dec(3) ctitle(goal margin) 

reg margin difhomereal ldifavvalue ldifnumber ldifnumbersupported if selector==1
estat ic, n(`games') 
outreg2 using Table8.xls, append keep(difhomereal ldifavvalue ldifnumber ldifnumbersupported) slow(750) dec(3) ctitle(goal margin) 

reg margin difhomereal ldifavvalue ldifnumber ldifsupportvalue if selector==1
estat ic, n(`games') 
outreg2 using Table8.xls, append keep(difhomereal ldifavvalue ldifnumber ldifsupportvalue) slow(750) dec(3) ctitle(goal margin) 

********************************************COMPARE FIT OF MODELS AT THE MATCH LEVEL********************************
keep if home==1

egen lossnull=mean(loss)
egen drawnull=mean(draw)
egen winnull=mean(win)

gen fitnull=winnull*win+drawnull*draw+lossnull*loss
gen fitodds=winodds*win+drawodds*draw+lossodds*loss
gen fitfifa=winfifa*win+drawfifa*draw+lossfifa*loss
gen fitelo=winelo*win+drawelo*draw+losselo*loss
gen fithat=winhat*win+drawhat*draw+losshat*loss
gen fitsup=winsup*win+drawsup*draw+losssup*loss
gen fitlogit=winlogit*win+drawlogit*draw+losslogit*loss
gen fitmlogit=winmlogit*win+drawmlogit*draw+lossmlogit*loss

***Geometric mean of fits

ameans fit* 

***Implied Log likelihood

gen lnull=log(fitnull)
gen lodds=log(fitodds)
gen lfifa=log(fitfifa)
gen lelo=log(fitelo)
gen lhat=log(fithat)
gen lsup=log(fitsup)
gen llogit=log(fitlogit)
gen lmlogit=log(fitmlogit)

egen llnull=total(lnull)
egen llodds=total(lodds)
egen llfifa=total(lfifa)
egen llelo=total(lelo)
egen llhat=total(lhat)
egen llsup=total(lsup)
egen lllogit=total(llogit)
egen llmlogit=total(lmlogit)

sum ll*

***Corealtion between fitted values
corr winhat winsup winodds winfifa winelo
corr drawhat drawsup drawodds drawfifa drawelo

log close 

clear


