version 14
cap log close
clear *
set more off

log using predictor.log, replace

use allgamesplayers.dta, replace

******************************************************VARIABLE GENERATION********************************************************************
sort date
egen matchday=group(date)
sum matchday
local maxmatchday=r(max)

sum loss draw win margin fifapoints fifarank wcqual10 wcqual14 euro12qual euro12 winodds drawodds lossodds homereal av* number* if selector==1

************************************************HOLD-OUT SAMPLE ESTIMATION AND FORECASTING ***************************************************

foreach name in null hat uefahat marginhat marginuefahat fifa uefafifa marginfifa marginuefafifa elo uefaelo marginelo marginuefaelo betwoc uefabetwoc {
gen loss`name'=.
gen draw`name'=.
gen win`name'=.
}

gen predmargin=.
gen predmarginuefa=.
gen predmarginfifa=.
gen predmarginuefafifa=.
gen predmarginelo=.
gen predmarginuefaelo=.


forvalues t=20(1)`maxmatchday'{
quietly{
noisily di `t' in yellow

*Estimation
*transfer model
oprobit res difhomereal ldifavvalue ldifnumber if selector==1 & matchday<`t', constraint(1)
predict losshat`t' drawhat`t' winhat`t'

reg margin difhomereal ldifavvalue ldifnumber if selector==1 & matchday<`t'
predict predmargin`t'
oprobit res predmargin`t' if matchday<`t'
predict lossmarginhat`t' drawmarginhat`t' winmarginhat`t'

oprobit res difhomereal ldifavvalue ldifnumber if selector==1 & matchday<`t' & uefa==1 & op_uefa==1, constraint(1)
predict lossuefahat`t' drawuefahat`t' winuefahat`t'

reg margin difhomereal ldifavvalue ldifnumber if selector==1 & matchday<`t' & uefa==1 & op_uefa==1
predict predmarginuefa`t'
oprobit res predmarginuefa`t' if matchday<`t' & uefa==1 & op_uefa==1
predict lossmarginuefahat`t' drawmarginuefahat`t' winmarginuefahat`t'

*FIFA model
oprobit res difhomereal ldiffifapoints ldifnumber if selector==1 & matchday<`t', constraint(1)
predict lossfifa`t' drawfifa`t' winfifa`t'

reg margin difhomereal ldiffifapoints ldifnumber if selector==1 & matchday<`t'
predict predmarginfifa`t'
oprobit res predmarginfifa`t' if matchday<`t'
predict lossmarginfifa`t' drawmarginfifa`t' winmarginfifa`t'

oprobit res difhomereal ldiffifapoints ldifnumber if selector==1 & matchday<`t' & uefa==1 & op_uefa==1, constraint(1)
predict lossuefafifa`t' drawuefafifa`t' winuefafifa`t'

reg margin difhomereal ldiffifapoints ldifnumber if selector==1 & matchday<`t' & uefa==1 & op_uefa==1
predict predmarginuefafifa`t'
oprobit res predmarginuefafifa`t' if matchday<`t' & uefa==1 & op_uefa==1
predict lossmarginuefafifa`t' drawmarginuefafifa`t' winmarginuefafifa`t'

*ELO model
oprobit res difhomereal ldifelopoints ldifnumber if selector==1 & matchday<`t', constraint(1)
predict losselo`t' drawelo`t' winelo`t'

reg margin difhomereal ldifelopoints ldifnumber if selector==1 & matchday<`t'
predict predmarginelo`t'
oprobit res predmarginelo`t' if matchday<`t'
predict lossmarginelo`t' drawmarginelo`t' winmarginelo`t'

oprobit res difhomereal ldifelopoints ldifnumber if selector==1 & matchday<`t' & uefa==1 & op_uefa==1, constraint(1)
predict lossuefaelo`t' drawuefaelo`t' winuefaelo`t'

reg margin difhomereal ldifelopoints ldifnumber if selector==1 & matchday<`t' & uefa==1 & op_uefa==1
predict predmarginuefaelo`t'
oprobit res predmarginuefaelo`t' if matchday<`t' & uefa==1 & op_uefa==1
predict lossmarginuefaelo`t' drawmarginuefaelo`t' winmarginuefaelo`t'

*Null model
egen lossnullsetup`t'=mean(loss)	if matchday<`t'
egen drawnullsetup`t'=mean(draw) 	if matchday<`t'
egen winnullsetup`t'=mean(win)		if matchday<`t'

egen lossnull`t'=mean(lossnullsetup`t')	
egen drawnull`t'=mean(drawnullsetup`t') 	
egen winnull`t'=mean(winnullsetup`t')

for var losshat drawhat winhat lossuefahat drawuefahat winuefahat lossmarginhat drawmarginhat winmarginhat predmargin ///
 lossmarginuefahat drawmarginuefahat winmarginuefahat predmarginuefa ///
 lossfifa drawfifa winfifa lossuefafifa drawuefafifa winuefafifa lossmarginfifa drawmarginfifa winmarginfifa predmarginfifa ///
 lossmarginuefafifa drawmarginuefafifa winmarginuefafifa predmarginuefafifa ///
 losselo drawelo winelo lossuefaelo drawuefaelo winuefaelo lossmarginelo drawmarginelo winmarginelo predmarginelo ///
 lossmarginuefaelo drawmarginuefaelo winmarginuefaelo predmarginuefaelo ///
 lossnull drawnull winnull: replace X=X`t' if matchday==`t'

 for var losshat drawhat winhat lossuefahat drawuefahat winuefahat lossmarginhat drawmarginhat winmarginhat predmargin ///
 lossmarginuefahat drawmarginuefahat winmarginuefahat predmarginuefa ///
 lossfifa drawfifa winfifa lossuefafifa drawuefafifa winuefafifa lossmarginfifa drawmarginfifa winmarginfifa predmarginfifa ///
 lossmarginuefafifa drawmarginuefafifa winmarginuefafifa predmarginuefafifa ///
 losselo drawelo winelo lossuefaelo drawuefaelo winuefaelo lossmarginelo drawmarginelo winmarginelo predmarginelo ///
 lossmarginuefaelo drawmarginuefaelo winmarginuefaelo predmarginuefaelo ///
 lossnull drawnull winnull: drop X`t'

 drop lossnullsetup`t' drawnullsetup`t' winnullsetup`t' 
} 
}

keep if home==1

save predictiondata.dta, replace
*/

******************************************ANALYZE THIS FILE TO JUDGE FORECASTING PERFORMANCE*********************************************

use predictiondata.dta

foreach name in null odds hat uefahat marginhat marginuefahat fifa uefafifa marginfifa marginuefafifa elo uefaelo marginelo marginuefaelo {

***Calculate fits
gen fit`name'=win`name'*win+draw`name'*draw+loss`name'*loss

***Predicted outcome	
gen outcome`name'=2		if win`name'>draw`name' & win`name'>loss`name'
replace outcome`name'=2	if win`name'==loss`name'
replace outcome`name'=0	if loss`name'>draw`name' & loss`name'>win`name'
replace outcome`name'=1	if outcome`name'==.

***Success Ratio
gen success`name'=1 		if outcome`name'==res
replace success`name'=0 	if success`name'==.

***Implied Log likelihood
gen l`name'=log(fit`name')
gen lfit`name'=-log(fit`name')

****Brier Score
gen brier`name'=1/3*((win`name'-win)^2+(draw`name'-draw)^2+(loss`name'-loss)^2)

}

*****************************************************BETTING STRATEGIES**********************************************************
gen reqover=1

foreach name in hat uefahat marginhat marginuefahat fifa uefafifa marginfifa marginuefafifa elo uefaelo marginelo marginuefaelo {

***WoC Model
*expected return
gen betwin`name'=odd_win*win`name'
gen betdraw`name'=odd_draw*draw`name'
gen betloss`name'=odd_loss*loss`name'

*decision to bet
gen putwin`name'=1 		if betwin`name'>reqover
replace putwin`name'=0 	if putwin`name'==.
gen putdraw`name'=1 	if betdraw`name'>reqover
replace putdraw`name'=0 if putdraw`name'==.
gen putloss`name'=1		if betloss`name'>reqover
replace putloss`name'=0 if putloss`name'==.

*stakes and number of bets
gen stakewin`name'=1/(odd_win-1) 	if putwin`name'==1
gen stakedraw`name'=1/(odd_draw-1) 	if putdraw`name'==1
gen stakeloss`name'=1/(odd_loss-1) 	if putloss`name'==1
gen stakekellywin`name'=((odd_win-1)*win`name'-(1-win`name'))/(odd_win-1) 		if putwin`name'==1
gen stakekellydraw`name'=((odd_draw-1)*draw`name'-(1-draw`name'))/(odd_draw-1) 	if putloss`name'==1
gen stakekellyloss`name'=((odd_loss-1)*loss`name'-(1-loss`name'))/(odd_loss-1) 	if putloss`name'==1
replace stakekellywin`name'=0 	if stakekellywin`name'==.
replace stakekellydraw`name'=0 	if stakekellydraw`name'==.
replace stakekellyloss`name'=0 	if stakekellyloss`name'==.
egen stakeunitwin`name'=rowtotal(stakewin`name' stakedraw`name' stakeloss`name')
egen stakekelly`name'=rowtotal(stakekellywin`name' stakekellydraw`name' stakekellyloss`name')
replace stakeunitwin`name'=. if stakeunitwin`name'==0
replace stakekelly`name'=. if stakekelly`name'==0

gen bets`name'=putwin`name'+putdraw`name'+putloss`name'

*return on actual bets
gen unitreturn`name'=win*putwin`name'*(odd_win-1)-(1-win)*putwin`name'+draw*putdraw`name'*(odd_draw-1)-(1-draw)*putdraw`name'+loss*putloss`name'*(odd_loss-1)-(1-loss)*putloss`name'
gen unitwin`name'=win*putwin`name'-(1-win)*putwin`name'*(1/(odd_win-1)) ///
+draw*putdraw`name'-(1-draw)*putdraw`name'*(1/(odd_draw-1)) ///
+loss*putloss`name'-(1-loss)*putloss`name'*(1/(odd_loss-1))
gen kelly`name'=win*putwin`name'*stakekellywin`name'*(odd_win-1)-(1-win)*putwin`name'*stakekellywin`name' ///
+draw*putdraw`name'*stakekellydraw`name'*(odd_draw-1)-(1-draw)*putdraw`name'*stakekellydraw`name' ///
+loss*putloss`name'*stakekellyloss`name'*(odd_loss-1)-(1-loss)*putloss`name'*stakekellyloss`name'

}

save predicted.dta, replace

***********************************ANALYSIS ON ALL GAMES**************************************

********Analysis all data points:
preserve
keep if losshat!=.

egen freqloss=mean(loss)
egen freqdraw=mean(draw)
egen freqwin=mean(win)
gen brierunc=1/3*(freqloss*(1-freqloss)+freqdraw*(1-freqdraw)+freqwin*(1-freqwin))

foreach name in null odds hat marginhat fifa marginfifa elo marginelo {

***Implied Log likelihood
egen ll`name'=total(l`name')

***Success Ratio
egen sr`name'=mean(success`name')

***Brier decomposition
xtile decloss`name'=loss`name', n(10)
xtile decdraw`name'=draw`name', n(10)
xtile decwin`name'=win`name', n(10)

bysort decloss`name': egen binavloss`name'=mean(loss)
bysort decloss`name': egen binavpredloss`name'=mean(loss`name')
bysort decdraw`name': egen binavdraw`name'=mean(draw)
bysort decdraw`name': egen binavpreddraw`name'=mean(draw`name')
bysort decwin`name': egen binavwin`name'=mean(win)
bysort decwin`name': egen binavpredwin`name'=mean(win`name')

egen brierrelloss`name'=mean((binavpredloss`name'-binavloss`name')^2)
egen brierreldraw`name'=mean((binavpreddraw`name'-binavdraw`name')^2)
egen brierrelwin`name'=mean((binavpredwin`name'-binavwin`name')^2)

egen briertotal`name'=mean(brier`name')
gen brierrel`name'=1/3*(brierrelloss`name'+brierreldraw`name'+brierrelwin`name')
gen briergres`name'=briertotal`name'-brierrel`name'-brierunc
}

ameans fitnull fitodds fithat fitmarginhat fitfifa fitmarginfifa fitelo fitmarginelo
tabstat brierunc brierrelnull brierrelodds brierrelhat brierrelmarginhat brierrelfifa brierrelmarginfifa brierrelelo brierrelmarginelo ///
briergresnull briergresodds briergreshat briergresmarginhat briergresfifa briergresmarginfifa briergreselo briergresmarginelo ///
briertotalnull briertotalodds briertotalhat briertotalmarginhat briertotalfifa briertotalmarginfifa briertotalelo briertotalmarginelo ///
lfitnull lfitodds lfithat lfitmarginhat lfitfifa lfitmarginfifa lfitelo lfitmarginelo ll* sr*, stat(co mean) col(stat) longstub

ttest brierhat==briernull
ttest briermarginhat==briernull

ttest brierhat==brierfifa
ttest briermarginhat==briermarginfifa

ttest brierhat==brierelo
ttest briermarginhat==briermarginelo

ttest brierhat==brierodds
ttest briermarginhat==brierodds

*********Regression of FE on TM values

cap erase Table5full.xls
cap erase Table5full.txt

foreach name in null odds fifa marginfifa elo marginelo {

gen winfe`name'=win-win`name'
gen drawfe`name'=draw-draw`name'
gen lossfe`name'=loss-loss`name'

***regression on market value
reg winfe`name' ldifavvalue
outreg2 using Table5full.xls, append keep(ldifavvalue ldifnumber) slow(750) dec(3) ctitle(win `name')  

reg drawfe`name' ldifavvalue 
outreg2 using Table5full.xls, append keep(ldifavvalue ldifnumber) slow(750) dec(3) ctitle(draw `name') 

reg lossfe`name' ldifavvalue 
outreg2 using Table5full.xls, append keep(ldifavvalue ldifnumber) slow(750) dec(3) ctitle(loss `name')  
}

*********************Bettting Return************
for var betshat betsfifa betselo betsmarginhat betsmarginfifa betsmarginelo ///
unitreturnhat unitreturnfifa unitreturnelo unitreturnmarginhat unitreturnmarginfifa unitreturnmarginelo ///
unitwinhat kellyhat unitwinfifa kellyfifa unitwinelo kellyelo ///
unitwinmarginhat kellymarginhat unitwinmarginfifa kellymarginfifa unitwinmarginelo kellymarginelo ///
stakeunitwinhat stakekellyhat stakeunitwinfifa stakekellyfifa stakeunitwinelo stakekellyelo ///
stakeunitwinmarginhat stakekellymarginhat stakeunitwinmarginfifa stakekellymarginfifa stakeunitwinmarginelo stakekellymarginelo: egen totalX=total(X)

for var unitreturnhat unitwinhat kellyhat stakeunitwinhat stakekellyhat: gen meanX=totalX/totalbetshat
for var unitreturnfifa unitwinfifa kellyfifa stakeunitwinfifa stakekellyfifa: gen meanX=totalX/totalbetsfifa
for var unitreturnelo unitwinelo kellyelo stakeunitwinelo stakekellyelo: gen meanX=totalX/totalbetselo
for var unitreturnmarginhat unitwinmarginhat kellymarginhat stakeunitwinmarginhat stakekellymarginhat: gen meanX=totalX/totalbetsmarginhat
for var unitreturnmarginfifa unitwinmarginfifa kellymarginfifa stakeunitwinmarginfifa stakekellymarginfifa: gen meanX=totalX/totalbetsmarginfifa
for var unitreturnmarginelo unitwinmarginelo kellymarginelo stakeunitwinmarginelo stakekellymarginelo: gen meanX=totalX/totalbetsmarginelo
 
sum totalbets* meanunitreturn* meanunitwin* meanstake* meankelly*

restore

**************************************Analysis last 60% of games***************************************************
preserve

*select last 60%

sum matchday

xtile matchdaybin=matchday, n(5)
drop if matchdaybin<3
keep if losshat!=.

egen freqloss=mean(loss)
egen freqdraw=mean(draw)
egen freqwin=mean(win)
gen brierunc=1/3*(freqloss*(1-freqloss)+freqdraw*(1-freqdraw)+freqwin*(1-freqwin))

foreach name in null odds hat marginhat fifa marginfifa elo marginelo {

***Implied Log likelihood
egen ll`name'=total(l`name')

***Success Ratio
egen sr`name'=mean(success`name')

***Brier decomposition
xtile decloss`name'=loss`name', n(10)
xtile decdraw`name'=draw`name', n(10)
xtile decwin`name'=win`name', n(10)

bysort decloss`name': egen binavloss`name'=mean(loss)
bysort decloss`name': egen binavpredloss`name'=mean(loss`name')
bysort decdraw`name': egen binavdraw`name'=mean(draw)
bysort decdraw`name': egen binavpreddraw`name'=mean(draw`name')
bysort decwin`name': egen binavwin`name'=mean(win)
bysort decwin`name': egen binavpredwin`name'=mean(win`name')

egen brierrelloss`name'=mean((binavpredloss`name'-binavloss`name')^2)
egen brierreldraw`name'=mean((binavpreddraw`name'-binavdraw`name')^2)
egen brierrelwin`name'=mean((binavpredwin`name'-binavwin`name')^2)

egen briertotal`name'=mean(brier`name')
gen brierrel`name'=1/3*(brierrelloss`name'+brierreldraw`name'+brierrelwin`name')
gen briergres`name'=briertotal`name'-brierrel`name'-brierunc
}


ameans fitnull fitodds fithat fitmarginhat fitfifa fitmarginfifa fitelo fitmarginelo
tabstat brierunc brierrelnull brierrelodds brierrelhat brierrelmarginhat brierrelfifa brierrelmarginfifa brierrelelo brierrelmarginelo ///
briergresnull briergresodds briergreshat briergresmarginhat briergresfifa briergresmarginfifa briergreselo briergresmarginelo ///
briertotalnull briertotalodds briertotalhat briertotalmarginhat briertotalfifa briertotalmarginfifa briertotalelo briertotalmarginelo ///
lfitnull lfitodds lfithat lfitmarginhat lfitfifa lfitmarginfifa lfitelo lfitmarginelo ll* sr*, stat(co mean) col(stat) longstub

ttest brierhat==briernull
ttest briermarginhat==briernull

ttest brierhat==brierfifa
ttest briermarginhat==briermarginfifa

ttest brierhat==brierelo
ttest briermarginhat==briermarginelo

ttest brierhat==brierodds
ttest briermarginhat==brierodds

*********Regression of FE on TM values 
cap erase Table5.xls
cap erase Table5.txt

foreach name in null odds fifa marginfifa elo marginelo {

gen winfe`name'=win-win`name'
gen drawfe`name'=draw-draw`name'
gen lossfe`name'=loss-loss`name'

***regression on market value
reg winfe`name' ldifavvalue 
outreg2 using Table5.xls, append keep(ldifavvalue ldifnumber) slow(750) dec(3) ctitle(win `name')  

reg drawfe`name' ldifavvalue 
outreg2 using Table5.xls, append keep(ldifavvalue ldifnumber) slow(750) dec(3) ctitle(draw `name') 

reg lossfe`name' ldifavvalue 
outreg2 using Table5.xls, append keep(ldifavvalue ldifnumber) slow(750) dec(3) ctitle(loss `name')  
}


*********************Bettting Return************
for var betshat betsfifa betselo betsmarginhat betsmarginfifa betsmarginelo ///
unitreturnhat unitreturnfifa unitreturnelo unitreturnmarginhat unitreturnmarginfifa unitreturnmarginelo ///
unitwinhat kellyhat unitwinfifa kellyfifa unitwinelo kellyelo ///
unitwinmarginhat kellymarginhat unitwinmarginfifa kellymarginfifa unitwinmarginelo kellymarginelo ///
stakeunitwinhat stakekellyhat stakeunitwinfifa stakekellyfifa stakeunitwinelo stakekellyelo ///
stakeunitwinmarginhat stakekellymarginhat stakeunitwinmarginfifa stakekellymarginfifa stakeunitwinmarginelo stakekellymarginelo: egen totalX=total(X)

for var unitreturnhat unitwinhat kellyhat stakeunitwinhat stakekellyhat: gen meanX=totalX/totalbetshat
for var unitreturnfifa unitwinfifa kellyfifa stakeunitwinfifa stakekellyfifa: gen meanX=totalX/totalbetsfifa
for var unitreturnelo unitwinelo kellyelo stakeunitwinelo stakekellyelo: gen meanX=totalX/totalbetselo
for var unitreturnmarginhat unitwinmarginhat kellymarginhat stakeunitwinmarginhat stakekellymarginhat: gen meanX=totalX/totalbetsmarginhat
for var unitreturnmarginfifa unitwinmarginfifa kellymarginfifa stakeunitwinmarginfifa stakekellymarginfifa: gen meanX=totalX/totalbetsmarginfifa
for var unitreturnmarginelo unitwinmarginelo kellymarginelo stakeunitwinmarginelo stakekellymarginelo: gen meanX=totalX/totalbetsmarginelo
 
sum totalbets* meanunitreturn* meanunitwin* meankelly* meanstake*

****The predictions in a scatter

foreach name in odds fifa elo {

twoway (scatter win`name' winhat)  (line winhat winhat, sort), ytitle(`name') xtitle(Transfermarkt) ysc(r(0 1)) xsc(r(0 1)) legend(off)
graph save scatterwin`name'.gph, replace

twoway (scatter draw`name' drawhat) (line drawhat drawhat, sort), ytitle(`name') xtitle(Transfermarkt) legend(off)
graph save scatterdraw`name'.gph, replace

twoway (scatter loss`name' losshat) (line losshat losshat, sort), ytitle(`name') xtitle(Transfermarkt) ysc(r(0 1)) xsc(r(0 1)) legend(off)
graph save scatterloss`name'.gph, replace

}
restore


****************************************Analysis on last 60% of UEFA games*************************
preserve

*select last 60% and UEFA

keep if uefa==1
keep if op_uefa==1

sum matchday

xtile matchdaybin=matchday, n(5)
drop if matchdaybin<3
keep if losshat!=.

egen freqloss=mean(loss)
egen freqdraw=mean(draw)
egen freqwin=mean(win)
gen brierunc=1/3*(freqloss*(1-freqloss)+freqdraw*(1-freqdraw)+freqwin*(1-freqwin))

foreach name in null odds uefahat marginuefahat uefafifa marginuefafifa uefaelo marginuefaelo {

***Implied Log likelihood
egen ll`name'=total(l`name')

***Success Ratio
egen sr`name'=mean(success`name')

***Brier decomposition
xtile decloss`name'=loss`name', n(10)
xtile decdraw`name'=draw`name', n(10)
xtile decwin`name'=win`name', n(10)

bysort decloss`name': egen binavloss`name'=mean(loss)
bysort decloss`name': egen binavpredloss`name'=mean(loss`name')
bysort decdraw`name': egen binavdraw`name'=mean(draw)
bysort decdraw`name': egen binavpreddraw`name'=mean(draw`name')
bysort decwin`name': egen binavwin`name'=mean(win)
bysort decwin`name': egen binavpredwin`name'=mean(win`name')

egen brierrelloss`name'=mean((binavpredloss`name'-binavloss`name')^2)
egen brierreldraw`name'=mean((binavpreddraw`name'-binavdraw`name')^2)
egen brierrelwin`name'=mean((binavpredwin`name'-binavwin`name')^2)

egen briertotal`name'=mean(brier`name')
gen brierrel`name'=1/3*(brierrelloss`name'+brierreldraw`name'+brierrelwin`name')
gen briergres`name'=briertotal`name'-brierrel`name'-brierunc
}

ameans fitnull fitodds fituefahat fitmarginuefahat fituefafifa fitmarginuefafifa fituefaelo fitmarginuefaelo

tabstat brierunc brierrelnull brierrelodds brierreluefahat brierrelmarginuefahat brierreluefafifa brierrelmarginuefafifa brierreluefaelo brierrelmarginuefaelo ///
briergresnull briergresodds briergresuefahat briergresmarginuefahat briergresuefafifa briergresmarginuefafifa briergresuefaelo briergresmarginuefaelo ///
briertotalnull briertotalodds briertotaluefahat briertotalmarginuefahat briertotaluefafifa briertotalmarginuefafifa briertotaluefaelo briertotalmarginuefaelo ///
lfitnull lfitodds lfituefahat lfitmarginuefahat lfituefafifa lfitmarginuefafifa lfituefaelo lfitmarginuefaelo ll* sr*, stat(co mean) col(stat) longstub

ttest brieruefahat==briernull
ttest briermarginuefahat==briernull

ttest brieruefahat==brieruefafifa
ttest briermarginuefahat==briermarginuefafifa

ttest brieruefahat==brieruefaelo
ttest briermarginuefahat==briermarginuefaelo

ttest brieruefahat==brierodds
ttest briermarginuefahat==brierodds

*********Regression of FE on TM values 
cap erase Table5uefa.xls
cap erase Table5uefa.txt

foreach name in null odds uefafifa marginuefafifa uefaelo marginuefaelo {

gen winfe`name'=win-win`name'
gen drawfe`name'=draw-draw`name'
gen lossfe`name'=loss-loss`name'

***regression on market value
reg winfe`name' ldifavvalue 
outreg2 using Table5uefa.xls, append keep(ldifavvalue ldifnumber) slow(750) dec(3) ctitle(win `name')  

reg drawfe`name' ldifavvalue 
outreg2 using Table5uefa.xls, append keep(ldifavvalue ldifnumber) slow(750) dec(3) ctitle(draw `name') 

reg lossfe`name' ldifavvalue 
outreg2 using Table5uefa.xls, append keep(ldifavvalue ldifnumber) slow(750) dec(3) ctitle(loss `name')  
}

*********************Bettting Return************
for var betsuefahat betsuefafifa betsuefaelo betsmarginuefahat betsmarginuefafifa betsmarginuefaelo ///
unitreturnuefahat unitreturnuefafifa unitreturnuefaelo unitreturnmarginuefahat unitreturnmarginuefafifa unitreturnmarginuefaelo ///
unitwinuefahat kellyuefahat unitwinuefafifa kellyuefafifa unitwinuefaelo kellyuefaelo ///
unitwinmarginuefahat kellymarginuefahat unitwinmarginuefafifa kellymarginuefafifa unitwinmarginuefaelo kellymarginuefaelo ///
stakeunitwinuefahat stakekellyuefahat stakeunitwinuefafifa stakekellyuefafifa stakeunitwinuefaelo stakekellyuefaelo ///
stakeunitwinmarginuefahat stakekellymarginuefahat stakeunitwinmarginuefafifa stakekellymarginuefafifa stakeunitwinmarginuefaelo stakekellymarginuefaelo: egen totalX=total(X)

for var unitreturnuefahat unitwinuefahat kellyuefahat stakeunitwinuefahat stakekellyuefahat: gen meanX=totalX/totalbetsuefahat
for var unitreturnuefafifa unitwinuefafifa kellyuefafifa stakeunitwinuefafifa stakekellyuefafifa: gen meanX=totalX/totalbetsuefafifa
for var unitreturnuefaelo unitwinuefaelo kellyuefaelo stakeunitwinuefaelo stakekellyuefaelo: gen meanX=totalX/totalbetsuefaelo
for var unitreturnmarginuefahat unitwinmarginuefahat kellymarginuefahat stakeunitwinmarginuefahat stakekellymarginuefahat: gen meanX=totalX/totalbetsmarginuefahat
for var unitreturnmarginuefafifa unitwinmarginuefafifa kellymarginuefafifa stakeunitwinmarginuefafifa stakekellymarginuefafifa: gen meanX=totalX/totalbetsmarginuefafifa
for var unitreturnmarginuefaelo unitwinmarginuefaelo kellymarginuefaelo stakeunitwinmarginuefaelo stakekellymarginuefaelo: gen meanX=totalX/totalbetsmarginuefaelo
 
sum totalbets* meanunitreturn* meanunitwin* meankelly* meanstake*

restore


clear*
log close
